@@ -1,5 +1,6 @@
 # flake8: noqa: W291
 # pylint: disable=too-many-lines,trailing-whitespace
+
 """
 annofabapiのmodelをDataClassで定義したクラス
 
@@ -16,7 +17,7 @@ from dataclasses_json import dataclass_json
 
 from annofabapi.models import InspectionStatus, TaskPhase
 
-OneOfInspectionDataPointInspectionDataPolylineInspectionDataTime = Dict[str, Any]
+InspectionData = Dict[str, Any]
 
 
 @dataclass_json
@@ -39,22 +40,22 @@ class Inspection:
     """検査ID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     phase: TaskPhase
-    """検査コメントを付与したときのタスクフェーズ。[詳細はこちら](#section/TaskPhase)"""
+    """"""
 
     phase_stage: int
     """検査コメントを付与したときのフェーズのステージ"""
 
     commenter_account_id: str
-    """検査コメントを付与したユーザのアカウントID"""
+    """"""
 
     annotation_id: Optional[str]
-    """検査コメントに紐づくアノテーションのID。アノテーションに紐付けられていない場合（アノテーションの付け忘れに対する指定など）は未指定。 [詳細はこちら](#section/AnnotationId)。 """
+    """アノテーションID。[値の制約についてはこちら。](#section/API-Convention/APIID)<br> annotation_type が classification の場合は label_id と同じ値が格納されます。 """
 
-    data: OneOfInspectionDataPointInspectionDataPolylineInspectionDataTime
-    """検査コメントの座標値や区間。  * `InspectionDataPoint`：点で検査コメントを付与したときの座標値 * `InspectionDataPolyline`：ポリラインで検査コメントを付与したときの座標値 * `InspectionDataTime`：検査コメントを付与した区間（動画プロジェクトの場合） """
+    data: InspectionData
+    """"""
 
     parent_inspection_id: Optional[str]
-    """返信先の検査コメントの検査ID。返信先の検査コメントは「スレッド内の直前のコメント」ではなく「スレッドの先頭のコメント」を指します。 """
+    """検査ID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     phrases: Optional[List[str]]
     """参照している定型指摘のID。"""
