@@ -271,7 +271,10 @@ class Wrapper:
         return detail
 
     def __to_dest_annotation_detail(
-        self, dest_project_id: str, detail: Dict[str, Any], account_id: str,
+        self,
+        dest_project_id: str,
+        detail: Dict[str, Any],
+        account_id: str,
     ) -> Dict[str, Any]:
         """
         コピー元の１個のアノテーションを、コピー先用に変換する。
@@ -473,7 +476,7 @@ class Wrapper:
 
         dest_obj = dict(
             label_id=label_info["label_id"],
-            annotation_id=detail["annotation_id"] if detail.get("annotation_id") is not None else str(uuid.uuid4()),
+            annotation_id=detail["annotation_id"] if detail["annotation_id"] is not None else str(uuid.uuid4()),
             account_id=self.api.account_id,
             data_holding_type=data_holding_type,
             data=detail["data"],
@@ -502,7 +505,7 @@ class Wrapper:
         input_data_id: str,
         simple_annotation_json: str,
         annotation_specs_labels: List[LabelV1],
-    ) -> bool:
+    ) -> None:
         """
         AnnoFabからダウンロードしたアノテーションzip配下のJSONと同じフォーマット（Simple Annotation)の内容から、アノテーションを登録する。
 
@@ -512,8 +515,6 @@ class Wrapper:
             input_data_id:
             simple_annotation_json:
 
-        Returns:
-            True:アノテーション情報をした。False: 登録するアノテーション情報がなかったため、登録しなかった。
         """
         parser = SimpleAnnotationDirParser(Path(simple_annotation_json))
         annotation = parser.load_json()
@@ -521,7 +522,7 @@ class Wrapper:
         details = annotation["details"]
         if len(details) == 0:
             logger.warning(f"simple_annotation_json='{simple_annotation_json}'にアノテーション情報は記載されていなかったので、スキップします。")
-            return False
+            return None
 
         request_details: List[Dict[str, Any]] = []
         for detail in details:
@@ -532,7 +533,7 @@ class Wrapper:
                 request_details.append(request_detail)
         if len(request_details) == 0:
             logger.warning(f"simple_annotation_json='{simple_annotation_json}'に、登録できるアノテーションはなかったので、スキップします。")
-            return False
+            return None
 
         old_annotation, _ = self.api.get_editor_annotation(project_id, task_id, input_data_id)
         updated_datetime = old_annotation["updated_datetime"] if old_annotation is not None else None
@@ -545,7 +546,7 @@ class Wrapper:
             "updated_datetime": updated_datetime,
         }
         self.api.put_annotation(project_id, task_id, input_data_id, request_body=request_body)
-        return True
+        return None
 
     #########################################
     # Public Method : AnnotationSpecs
@@ -980,6 +981,7 @@ class Wrapper:
         input_data_id: str,
         filter_inspection: Callable[[Inspection], bool],
         inspection_status: InspectionStatus,
+        updated_datetime: Optional[str] = None,
     ) -> List[Inspection]:
         """
         検査コメント（返信コメント以外）のstatusを変更する。
@@ -990,6 +992,7 @@ class Wrapper:
             input_data_id: 入力データID
             filter_inspection: 変更対象の検査コメントを絞り込む条件
             inspection_status: 検査コメントのstatus
+            updated_datetime: 検査コメントの更新日時。タスクの更新日時以降を指定する必要があります。Noneの場合、現在時刻を指定します。
 
         Returns:
             `batch_update_inspections` メソッドのcontent
@@ -1007,12 +1010,11 @@ class Wrapper:
 
         target_inspections = [e for e in inspections if search_updated_inspections(e)]
 
+        if updated_datetime is None:
+            updated_datetime = str_now()
         for inspection in target_inspections:
             inspection["status"] = inspection_status.value
-            if inspection["updated_datetime"] is None:
-                inspection["updated_datetime"] = inspection["created_datetime"]
-            else:
-                inspection["updated_datetime"] = str_now()
+            inspection["updated_datetime"] = updated_datetime
 
         req_inspection = [{"data": e, "_type": "Put"} for e in target_inspections]
         content = self.api.batch_update_inspections(project_id, task_id, input_data_id, req_inspection)[0]
